package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`%0`!````/"4```````!``````````&`!`0``
M`````@```$``.``(`$``%@`5``8````$````0`````````!``````````$``
M````````P`$```````#``0````````@``````````P````0``````@``````
M```"``````````(````````>`````````!X``````````0`````````!````
M!0```````````````````````````````````$RA````````3*$`````````
M``$```````$````&````$/L````````0^P$``````!#[`0``````:`4`````
M``#`!0```````````0```````@````8````@^P```````"#[`0``````(/L!
M`````````@`````````"````````"`````````!0Y71D!````,2;````````
MQ)L```````#$FP```````-P`````````W``````````$`````````%'E=&0&
M`````````````````````````````````````````````````````````!``
M````````4N5T9`0````0^P```````!#[`0``````$/L!``````#P!```````
M`/`$`````````0`````````O;&EB+VQD+6UU<VPM<&]W97)P8S8T;&4N<V\N
M,0```!$```!A````!`````@````@$!``!4`$@"@`$`2`A@"$@B$```D`!`F(
M@!A!N@0""`````!A````90```&D```!J````<````'$```!R`````````'0`
M``!U`````````'8```!W````>0``````````````:G^:?.K3[P[.WD<M;\7?
M'R[%F[:XC?$.U&34?"'_Y`[9<5@<^J%L8,+E/RRR`8MO0OK7A^)'Q@&[XY)\
M5<,\TF>OS&:(!W#30T75[#-BV^T5C"7,?ZF<F^"G`@IK&IY0H^#[20``````
M```````````````````````````````#``<`F!L`````````````````````
M```#`!(````"`````````````````"`#```"``@`6%D`````````````````
M`"T#```"``@`5%D``````````````````#H#```"``@`4%D`````````````
M`````$<#```"``@`3%D``````````````````%0#```"``@`1%D`````````
M`````````&$#```"``@`N%D``````````````````&X#```"``@`O%D`````
M`````````````'L#```"``@`2%D``````````````````*\#```"``@`:%D`
M`````````````````+P#```"``@`9%D``````````````````,D#```"``@`
M7%D``````````````````-8#```"``@`8%D```````````````````H$```"
M``@`;%D``````````````````!<$```"``@`<%D``````````````````"0$
M```"``@`H%D``````````````````#$$```"``@`A%D`````````````````
M`#X$```"``@`@%D``````````````````$L$```"``@`C%D`````````````
M`````%@$```"``@`B%D``````````````````&4$```"``@`?%D`````````
M`````````*$$```"``@`D%D``````````````````+@$```"``@`E%D`````
M`````````````,4$```"``@`F%D``````````````````-($```"``@`G%D`
M``````````````````$````28`````````````````````````D````1````
M`````````````````````,$!```1`````````````````````````$H!```2
M8````````````````````````!`````28````````````````````````)H!
M```28````````````````````````!@````28```````````````````````
M`,X!```28````````````````````````*8!```28```````````````````
M`````!\````@`````````````````````````-$"```A````````````````
M`````````#<````28````````````````````````#T````2````````````
M`````````````$0````2`````````````````````````(@"```28```````
M`````````````````*8"```28````````````````````````$L````2````
M`````````````````````.D!```28````````````````````````%(````2
M8````````````````````````&\"```28````````````````````````%D`
M```28````````````````````````&$````2````````````````````````
M`($"```28````````````````````````&D````28```````````````````
M`````%@"```28````````````````````````'$````28```````````````
M`````````'<````28````````````````````````(`````@````````````
M`````````````)@"```28````````````````````````)P````28```````
M`````````````````*$````28````````````````````````&<!```6````
M`````````````````````'8"```28````````````````````````!8"```2
M8````````````````````````*@````28`````````````````````````@"
M```28````````````````````````!<#```28```````````````````````
M`-`"```1`````````````````````````#H"```28```````````````````
M`````+T"```28````````````````````````-("```1````````````````
M`````````*\````28````````````````````````%@!```28```````````
M`````````````+@````B`````````````````````````,<````@````````
M`````````````````-T````28````````````````````````+4"```28```
M`````````````````````"8"```28````````````````````````.(````2
M8````````````````````````.@````@`````````````````````````&,"
M```28`````````````````````````(!```28```````````````````````
M`(L!```28`````````````````````````<!```28```````````````````
M`````$@"```28````````````````````````'H!```28```````````````
M``````````T!```2`````````````````````````!X!```28```````````
M`````````````.0!```28````````````````````````'(````28```````
M`````````````````/4!```28````````````````````````"\"```28```
M`````````````````````)\"```28````````````````````````)`"```2
M8````````````````````````"0!```2`````````````````````````-\!
M```28````````````````````````"L!```2````````````````````````
M`#(!```2`````````````````````````,\"```A````````````````````
M`````$,!```2`````````````````````````,H"```28`@``",````````\
M`@```````+L!```28`D`]%H````````0`````````/4#```28`@`&#8`````
M``!`!P```````#T%```28`@`M#\```````"8`````````)X#```28`@`2"\`
M```````8`````````/L$```28`<`F!L````````0`````````(`$```28`@`
M6#T```````!<`@```````"$%```28`@`8"\```````!(`@```````.P$```0
M`!,`>``"`````````````````.,#```28`@`5#4```````#$``````````($
M```28`@`G"T```````!@`````````'($```28`@`>#0```````"0````````
M`)8$```28`@`;%8````````T`0```````-\$```28`@`J#$```````!4````
M`````#@%```0`!,`T``"`````````````````/P"```28`@`:"4```````!<
M``````````$%```28`@`_#$````````\`0```````*X$```1`!(`<``"````
M```(`````````!H%```0`!(`>``"`````````````````/$$```2``@`/"4`
M`````````````````/@$```28`@`V%4```````"4``````````4#```28`@`
M"#4```````!,`````````(@#```28`@`:"X```````#@`````````"X%```2
M8`@`H%<```````"D`0````````T%```28`@`.#,```````!``0````````!O
M<&5N9&ER`'-T9&5R<@!R96%L;&]C`&%C8V5S<P!?7V1E<F5G:7-T97)?9G)A
M;65?:6YF;P!L<V5E:P!G971P:60`<W1R8VUP`&UE;7-E=`!U;FQI;FL`;65M
M;6]V90!S=')N8VUP`'-T<G)C:'(`;'-T870`8VQO<V5D:7(`7TE435]D97)E
M9VES=&5R5$U#;&]N951A8FQE`&]P96X`<W1R<W1R`'-T<F-H<@!R96%D;&EN
M:P!?7V-X85]F:6YA;&EZ90!?7W)E9VES=&5R7V9R86UE7VEN9F\`97AI=`!C
M;&]S90!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`')E860`<FUD:7(`7U]E
M<G)N;U]L;V-A=&EO;@!M:V1I<@!M96UC<'D`<W1R;&5N`%]?<W1A8VM?8VAK
M7V9A:6P`9V5T=6ED`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`4$Q?
M8W5R<F5N=%]C;VYT97AT`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS=')U
M8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`7V9I;FD`4$Q?
M9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`<&5R;%]F<F5E`%!E<FQ?;6=?
M<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?
M9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`8F]O
M=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E
M<FQ?86QL;V,`<W1R8W!Y`')E861D:7(`<W!R:6YT9@!S=')D=7``<W1R=&]K
M`'!T:')E861?871F;W)K`&9P<FEN=&8`7U]L:6)C7W-T87)T7VUA:6X`7U]?
M96YV:7)O;@!L:6)P97)L+G-O`&QI8F,N;75S;"UP<&,V-&QE+G-O+C$`7W-T
M87)T7V,`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`7W-A=F5G<'(P7S(U
M`%]S879E9W!R,%\R-`!?<V%V96=P<C!?,C,`7W-A=F5G<'(P7S(R`%]S879E
M9W!R,%\R,`!?<F5S=&=P<C!?,S``7W)E<W1G<'(P7S,Q`%]S879E9W!R,%\R
M,0!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V-U<G)E;G1?97AE8P!?<V%V
M96=P<C!?,CD`7W-A=F5G<'(P7S(X`%]S879E9W!R,%\R-@!?<V%V96=P<C!?
M,C<`<&%R7W-E='5P7VQI8G!A=&@`<&%R7VUK=&UP9&ER`'AS7VEN:70`7W-A
M=F5G<'(P7S,P`%]S879E9W!R,%\S,0!?<F5S=&=P<C!?,CD`7W)E<W1G<'(P
M7S(R`%]R97-T9W!R,%\R,0!?<F5S=&=P<C!?,C0`7W)E<W1G<'(P7S(S`%]R
M97-T9W!R,%\R,`!P87)?96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?0D]/
M5`!S:&%?=7!D871E`%]R97-T9W!R,%\R-0!M>5]P87)?<&P`7W)E<W1G<'(P
M7S(V`%]R97-T9W!R,%\R-P!?<F5S=&=P<C!?,C@`<&%R7V)A<V5N86UE`%]?
M8G-S7W-T87)T`'-H85]I;FET`'!A<E]D:7)N86UE`'!A<E]I;FET7V5N=@!?
M961A=&$`<&%R7V9I;F1P<F]G`'-H85]F:6YA;`!?96YD`'!A<E]C;&5A;G5P
M`"]U<W(O;&EB+W!E<FPU+V-O<F5?<&5R;"]#3U)%```0^P$``````!8`````
M````,"<````````8^P$``````!8`````````H"8```````````(``````!8`
M```````````"```````0``(``````!8`````````OET````````8``(`````
M`!8`````````&5L````````H``(``````!8`````````^EL````````P``(`
M`````!8`````````\UL````````X``(``````!8`````````LET```````!`
M``(``````!8`````````$%P```````!(``(``````!8`````````NET`````
M``!8``(``````!8`````````I%T```````!@``(``````!8`````````J5T`
M``````!P``(``````!8`````````PUT````````(_P$``````"8````V````
M```````````0_P$``````"8```!,```````````````8_P$``````"8```!&
M```````````````@_P$``````"8````D```````````````H_P$``````"8`
M``!'```````````````P_P$``````"8```!#```````````````X_P$`````
M`"8```!1``````````````!`_P$``````"8````<``````````````!(_P$`
M`````"8```!7``````````````!0_P$``````"8```!2``````````````!8
M_P$``````"8````=``````````````!@_P$``````$D````Z````````````
M```P_0$``````!4````;```````````````X_0$``````!4````>````````
M``````!`_0$``````!4````?``````````````!(_0$``````!4````@````
M``````````!0_0$``````!4````A``````````````!8_0$``````!4````B
M``````````````!@_0$``````!4````C``````````````!H_0$``````!4`
M```D``````````````!P_0$``````!4````F``````````````!X_0$`````
M`!4````G``````````````"`_0$``````!4````H``````````````"(_0$`
M`````!4````I``````````````"0_0$``````!4````J``````````````"8
M_0$``````!4````K``````````````"@_0$``````!4````L````````````
M``"H_0$``````!4````M``````````````"P_0$``````!4````N````````
M``````"X_0$``````!4````O``````````````#`_0$``````!4````P````
M``````````#(_0$``````!4````Q``````````````#0_0$``````!4````R
M``````````````#8_0$``````!4````S``````````````#@_0$``````!4`
M```T``````````````#H_0$``````!4````U``````````````#P_0$`````
M`!4````W``````````````#X_0$``````!4````X````````````````_@$`
M`````!4````Y```````````````(_@$``````!4````[```````````````0
M_@$``````!4````\```````````````8_@$``````!4````]````````````
M```@_@$``````!4````^```````````````H_@$``````!4````_````````
M```````P_@$``````!4```!!```````````````X_@$``````!4```!"````
M``````````!`_@$``````!4```!$``````````````!(_@$``````!4```!%
M``````````````!0_@$``````!4```!&``````````````!8_@$``````!4`
M``!'``````````````!@_@$``````!4```!(``````````````!H_@$`````
M`!4```!)``````````````!P_@$``````!4```!*``````````````!X_@$`
M`````!4```!+``````````````"`_@$``````!4```!-``````````````"(
M_@$``````!4```!.``````````````"0_@$``````!4```!/````````````
M``"8_@$``````!4```!0``````````````"@_@$``````!4```!3````````
M``````"H_@$``````!4```!4``````````````"P_@$``````!4```!5````
M``````````"X_@$``````!4```!6``````````````#`_@$``````!4```!8
M``````````````#(_@$``````!4```!9``````````````#0_@$``````!4`
M``!:``````````````#8_@$``````!4```!;``````````````#@_@$`````
M`!4```!<``````````````#H_@$``````!4```!=``````````````#P_@$`
M`````!4```!>``````````````#X_@$``````!4```!@```````````````"
M`$P\:&-".*8""'P0``'XX?\A^"``(3@0``'HI@,(?"``@$X`````&`!!^/__
M@CV(?HSII@.)?2`$@$X````````````````8`$'X__^"/6A_C.FF`XE](`2`
M3@```````````````!@`0?C__X(]V'^,Z:8#B7T@!(!.````````````````
M&`!!^/__@CV(?XSII@.)?2`$@$X````````````````8`$'X__^"/2!_C.FF
M`XE](`2`3@```````````````!@`0?C__X(]0'Z,Z:8#B7T@!(!.````````
M````````&`!!^/__@CTX?HSII@.)?2`$@$X````````````````8`$'X__^"
M/5!^C.FF`XE](`2`3@```````````````!@`0?C__X(]L'^,Z:8#B7T@!(!.
M````````````````&`!!^/__@CW`?HSII@.)?2`$@$X````````````````8
M`$'X__^"/8!_C.FF`XE](`2`3@```````````````!@`0?C__X(]&'^,Z:8#
MB7T@!(!.````````````````&`!!^/__@CUX?HSII@.)?2`$@$X`````````
M```````8`$'X__^"/<A^C.FF`XE](`2`3@```````````````!@`0?C__X(]
MH'Z,Z:8#B7T@!(!.````````````````&`!!^/__@CUX?XSII@.)?2`$@$X`
M```````````````8`$'X__^"/5A^C.FF`XE](`2`3@```````````````!@`
M0?C__X(]$'^,Z:8#B7T@!(!.````````````````&`!!^/__@CVX?XSII@.)
M?2`$@$X````````````````8`$'X__^"/4A^C.FF`XE](`2`3@``````````
M`````!@`0?C__X(]8'Z,Z:8#B7T@!(!.````````````````&`!!^/__@CU8
M?XSII@.)?2`$@$X````````````````8`$'X__^"/>A_C.FF`XE](`2`3@``
M`````````````!@`0?C__X(]^'Z,Z:8#B7T@!(!.````````````````&`!!
M^/__@CT`?XSII@.)?2`$@$X````````````````8`$'X__^"/2A_C.FF`XE]
M(`2`3@```````````````!@`0?C__X(],'^,Z:8#B7T@!(!.````````````
M````&`!!^/__@CWH?HSII@.)?2`$@$X````````````````8`$'X__^"/:!_
MC.FF`XE](`2`3@```````````````!@`0?C__X(]\'Z,Z:8#B7T@!(!.````
M````````````&`!!^/__@CV8?HSII@.)?2`$@$X````````````````8`$'X
M__^"/>!^C.FF`XE](`2`3@```````````````!@`0?C__X(]T'^,Z:8#B7T@
M!(!.````````````````&`!!^/__@CV0?XSII@.)?2`$@$X`````````````
M```8`$'X__^"/0A_C.FF`XE](`2`3@```````````````!@`0?C__X(]0'^,
MZ:8#B7T@!(!.````````````````&`!!^/__@CWP?XSII@.)?2`$@$X`````
M```````````8`$'X__^"/5!_C.FF`XE](`2`3@```````````````!@`0?C_
M_X(].'^,Z:8#B7T@!(!.````````````````&`!!^/__@CV0?HSII@.)?2`$
M@$X````````````````8`$'X__^"/?A_C.FF`XE](`2`3@``````````````
M`!@`0?C__X(]F'^,Z:8#B7T@!(!.````````````````&`!!^/__@CU(?XSI
MI@.)?2`$@$X````````````````8`$'X__^"/<A_C.FF`XE](`2`3@``````
M`````````!@`0?C__X(]X'^,Z:8#B7T@!(!.````````````````&`!!^/__
M@CVP?HSII@.)?2`$@$X````````````````8`$'X__^"/6A^C.FF`XE](`2`
M3@```````````````!@`0?C__X(],'Z,Z:8#B7T@!(!.````````````````
M&`!!^/__@CVH?HSII@.)?2`$@$X````````````````8`$'X__^"/<!_C.FF
M`XE](`2`3@```````````````!@`0?C__X(]V'Z,Z:8#B7T@!(!.````````
M````````&`!!^/__@CVH?XSII@.)?2`$@$X````````````````8`$'X__^"
M/7!_C.FF`XE](`2`3@```````````````!@`0?C__X(]8'^,Z:8#B7T@!(!.
M````````````````&`!!^/__@CW0?HSII@.)?2`$@$X````````````````8
M`$'X__^"/7!^C.FF`XE](`2`3@```````````````!@`0?C__X(]N'Z,Z:8#
MB7T@!(!.````````````````&`!!^/__@CV`?HSII@.)?2`$@$X`````````
M```````"`$P\`%Q".*8""'SX_^'[$``!^''_(?AP`('X:`"A^'``@3AH`*$X
M?`!AD'P`83C1_?]+&`!!Z````&!(@*+H````8%"`8NAX*Z1\5?W_2Q@`0>@`
M``!@6(`BZ0``Z8L``!\L1`""0)G\_TL8`$'H````8```(RS(@6+X$`""0`$`
M8#C=_O]+&`!!Z%7\_TL8`$'H````8&"`(ND4:BE]```IZ:<+Z9L```!@?`!A
M@&"`(ND4:BE]`P#C.P0`8S@``$GIM`=C?"0?8WCZ!2J)`P`I8?H%*IDI^?]+
M&`!!Z'``X>@```!@?`!!@0```#FX@6+X>!MF?```)^D```HL```C^?[_(CV>
MWBDY"``C^0```&!P@2+I$``C^?[_(CVAWBDY&``C^?__*CD@`"EY`0`I.0@`
M@4$!`"`Y`0`I+`0`2#FT!TI]`0`(.20?2GG__RDYS`""0```(#D```!@R(%B
MZ/[_@CRT!^5_``#@."I1)GW\KH0XB?W_2Q@`0>@```,L>!M_?!@`@D````!@
MR(%BZ*W]_TL8`$'H>!M_?````&#(@6+H6?K_2Q@`0>C^_V(\K=QC.*4#`$@`
M`",L/`""0````&#`@2+I```I+!@`@D#^_V(\8MQC.($#`$@```!@P(%B^```
M`&#`@6+H```C+`@`@D'%&@!(````8,B!8N@]_/]+&`!!Z'7W_TL8`$'HD``A
M.+0'XW^@-`!()!\%>2HHIWPJ4:9\$/__2P`````````!@`$```(`3#S$64(X
M*`",@!1BA'QX"R-\Y`8A>````#CA_P'XI@,(?!$``$CDU0$``@!,/)A90CBF
M`@A\"`"C./[_XCSTV^<X_O_"/)B<QC@"`(/H_O]B/`"D8S@````Y$``!^.'_
M(?CA^O]+&`!!Z"``(3@0``'HI@,(?"``@$X``````````8````````!@````
M8````&`"`$P\,%E".````&````!@>(%B.'B!(CD`&"E\(`""30```&`(@(+I
M```L+"``@DVF`@A\I@.)?1```?CA_R'X&`!!^"$$@$X8`$'H(``A.!```>BF
M`PA\(`"`3@``0F`"`$P\T%A".````&````!@>(%B.'B!@CA0((-\=!Z$?'0.
MA'R5`81\(`""30```&`0@(+I```L+"``@DVF`@A\I@.)?1```?CA_R'X&`!!
M^"$$@$X8`$'H(``A.!```>BF`PA\(`"`3@```&```$)@`@!,/&!80C@```!@
M>($BB0``"2P@`(),I@((?````&`8@"+I```I+!```?CA_R'X%`""00```&``
M@6+HA?G_2Q@`0>CU_O]+````8""`(ND``"DL%`""0?[_8CS,'6,X@?K_2Q@`
M0>@@`"$X`0`@.0```&`0``'H>($BF:8#"'P@`(!.````8````&```$)@`@!,
M/-!70C@```!@*(`BZ0``*2P\`()!I@((?````&#^_V(\@(&".,P=8S@0``'X
MX?\A^/WV_TL8`$'H(``A.!```>BF`PA\P/[_2P``0F"X_O]+`@!,/'Q70CBF
M`@A\S3$`2'D;?'RQ_R'X``#`.R0`@D$```!@,(`BZ0``P#MX(YI\>..%?P``
MJ>L``#TL'`""0%``(3AX\\-_R#$`2#T`"2P4`()!`0"E.```)8D```DL[/^"
M0%`HO'QXZ[M_M`>_?```V^L``#XLR/^"07C[Y7]XXX1_>//#?]7T_TL8`$'H
M```#+"@`@D"N^#Y]/0`)+!P`@D!0V+U_`0#_.W0>O7\4^MY_``"ZDXC__TL(
M`'L[L/__2P`````````!@`8```(`3#RL5D(XI@((?!```?B1_R'X9`"!./"/
M+>EH`"'Y```@.17__TMH`$'I\(\MZ7E*2GT``"`Y#`""0;'W_TL8`$'H<``A
M.!```>BF`PA\(`"`3@`````````!@`````(`3#Q,5D(XI@((?/#_P?OX_^'[
M>!M_?!```?B!_R'X\(\MZ6@`(?D``"`Y9`#!.WCSQ']X^^-_H?[_2P``(RP@
M`()`:`!!Z?"/+>EY2DI]```@.3P`@D$U]_]+&`!!Z&8`0>D```!@,(`BZ0``
M*>DD'TIY^/]*.112*7T0`$GI```J+`D`2?GT_X)`I/__2X``(3AP,`!(````
M``````&``@```@!,/*A50CBF`@A\^/_A^W@;?WP0``'X,?\A^"@`@3CPCRWI
MN``A^0``(#D=]O]+&`!!Z```(#D```,L/`""0$``08$F!$I5`$`**!0`@D'_
M_TAM>!MI?`"@""P<`()``@"`.'C[XW_A\O]+&`!!Z#0`:7Q^V2E5M`<C?;@`
M0>GPCRWI>4I*?0``(#D,`()!6?;_2Q@`0>C0`"$XR"\`2``````````!@`$`
M``(`3#S\5$(XI@((?$TO`$C1_B'X>1M^?/"/+>GX`"'Y```@.5P`@D$``#Z)
M```)+%``@D%I]_]+&`!!Z'D;?'Q``()!_O]B/_[_0C\9W'L[&-Q:.WCC@W]E
M\?]+&`!!Z'D;?WPX`()`>..#?['T_TL8`$'H>//#?V7V_TL8`$'H^`!!Z?"/
M+>EY2DI]```@.=@`@D&I]?]+&`!!Z!,`_SMXVV1_>/OC?S7X_TL8`$'H```#
M+*#_@D%XTT1_>/OC?QWX_TL8`$'H```#+(C_@D%X\\-_J?/_2Q@`0>AX&WU\
M>/OC?YGS_TL8`$'H%!I]?`(`8SBT!V-\9?;_2Q@`0>C^_X(\>/OF?WCSQ7\;
MW(0X>!M]?*GT_TL8`$'H:`"!.'CKHW_9\O]+&`!!Z/__`RQXZZ-_*`""08``
M(8$F!"E5`$`)+!@`@D#!_O]+>.NC?VWQ_TL8`$'H_/[_2V'V_TL8`$'HZ/__
M2S`!(3@D+@!(``````````&`!@```@!,/(!30CBF`@A\S2T`2%'_(?AX&W]\
M>".>?/"/+>EH`"'Y```@.0``)(D]``DL"`""0`$`Q#MX\\-_Q?+_2Q@`0>AD
M`($X>!M]?'C[XW^]^_]+>1M\?$P`@D&E\O]+&`!!Z$`8/7RX`(%!``!`.:Y0
M/GVN43Q]/@8I50$`2CD```DL[/^"0&@`0>GPCRWI>4I*?0``(#EP`8)!)?3_
M2Q@`0>@```!@,(!BZP``(#D``#OK^/\9.7A+/'T!`"DY)!\J>2I02'T``"HL
M[/^"0````&"P@2*!`@"<.+0'A'PD'X1X```)+-P`@D%XRR-_\>__2Q@`0>@`
M`",L``![^(C_@D$!`#PY``!;Z0```#ED`(&3M`<I?20?*7DJ20I]>/OI?P``
M28D```HL#`""03T`"BS,`()`9@"!ZP```&`P@&+K4$@_?0(`?3BT!RE]%!II
M?```6^N)]/]+&`!!Z"0?G'L``",L*N%Z?!S_@D$``#OI____.RK@*7T!`%^-
M>$LH?0$`*3G__TF9_P!*<0P`@D$]``HLY/^"0#T`0#D``$B9````.:Y`7GVN
M04E]/@9*50$`"#D```HL[/^"0,C^_TL!`"`Y````8'@C@WRP@2*1#?3_2Q@`
M0>AY&WI\J/Z"0;0'A7]XRR1_)!^E>%'U_TL8`$'H``!;^PC__TL!`"DY(/__
M2[``(3@$+`!(``````````&`!P```@!,/&110CBF`@A\````8````&`X@*+H
M8(`BZ?[_PCP4:BE]_O^"/+@<QC@AW(0X$``!^.'_(?@``&GH"?3_2Q@`0>@@
M`"$X$``!Z*8#"'P@`(!.``````````&``````@!,/`110CBF`@A\^/_A^P``
M`&!@@.+K%&K_?Q```?C1_R'X``!_Z('__TL``'_H_O_B//[_HCR=WN<X_O^"
M/````#EX.^9\6+ZE.#W<A#AU[_]+&`!!Z#``(3AD*P!(``````````&``0``
M`@!,/)A00CBF`@A\]2H`2&'?(?CPCRWI>"`A^0``(#FY[O]+&`!!Z&@`X3O^
M_\(\_O^"/'@;97Q2W,8X5MR$.'C[XW]P$*$[$?'_2Q@`0>@`$*`X>.ND?WC[
MXW]=\?]+&`!!Z````RP@`(!!>!M_?`$`8SBT!V-\@?+_2Q@`0>AY&WY\)`""
M0```P#MX($'I\(\MZ7E*2GT``"`Y+`""03GQ_TL8`$'HM`?_?WCKI']X^^5_
MY>S_2Q@`0>@``"`YKOD^?<C__TN@("$X>//#?V@J`$@``````````8`#```"
M`$P\N$]"."#__TL````````````````"`$P\H$]".*8""'PF@'!]"`!AD=$I
M`$BA[B'X>!M^?/[_8CQBW&,X>".??/"/+>GX$"'Y```@.<7X_TLO`(`X>!M[
M?'CSPW]Y[?]+&`!!Z```(RPP`()!_O]B/'CSQ']KW&,XQ?O_2_@00>GPCRWI
M>4I*?0``(#FP`8)!9?#_2Q@`0>AX^^-__O]"/W7O_TL8`$'H>-Q:._[_(C]X
MTT1__O_B/AWQ_TL8`$'H_O_"/@``@#H``#LN&=PY.W@;?WP````[>MSW.DO=
MUCKX`($[:`"A.@"`E&(``#\L?/^"00``/XD```DL"`""0'C+/W\<`))!>/OD
M?WC;8W^%\O]+&`!!Z````RP(`8)!>/OC?Q'N_TL8`$'H%!H_??__0SG__RDY
M%%(??4!(/WQX&VI\#`"!0?__/RP(`()``0!`.0$`*BS__THY$`""00``*(DO
M``DLL`""07C[XW_%[?]+&`!!Z'@;?7QX\\-_M>W_2Q@`0>@4&KU_`0"]._\/
M/2C8_H%!>//'?WB[YGYX^^5_>+/$?GCC@W_)[O]+&`!!Z'BKI'YXXX-_^>S_
M2Q@`0>@```,L7`""0(``(8$F!"E5`*`)?$P`@D`!`(`X>..#?W'K_TL8`$'H
M```#+#0`@D#^_V(\>..$?VO<8S@]^O]+>..#?PWN_TL8`$'H>!M^?&C^_TL`
M``B;__\(.33__TMXTT1_``!@.*GO_TL8`$'H>!M_?+3^_TM@$2$X>//#?P@`
M88$@@7!]Y"<`2``````````#@`P```(`3#Q834(XI@((?/C_X?LO`(`X>!M_
M?!```?C1_R'XN?#_2Q@`0>@``",L"`""00$`XSMX^^-_@>W_2Q@`0>@P`"$X
MT"<`2``````````!@`$```(`3#P$34(XI@((?/#_P?OX_^'[>1M^?!```?C!
M[R'X\(\MZ2@0(?D``"`Y$`""00``/HD```DL,`""0/[_8CP9W&,X(>W_2Q@`
M0>@H$$'I\(\MZ7E*2GT``"`YS`""0>7M_TL8`$'H'>S_2Q@`0>@!`",Y``!@
M.``0*2C0_X%!*`#A.WCSQ']X^^-_V>K_2Q@`0>AX^^-_[>O_2Q@`0>@``.`X
M__\C.3`0`SD42E]]>!MI?!0*:'SW[V,X0!@_?!``@4$P$`$Y!Q`H+`@`@D`!
M`"`Y`0`I+/__*3D0`()!```*B2\`""PT`()!+P"`.'C[XW^1[_]+&`!!Z```
M(RP\_X)!0/@C?`P`@4```"`Y```CF7C[XW\L__]+``#JF/__2CFP__]+0!`A
M.)`F`$@``````````8`"```"`$P\R$M".*8""'S^_V(\?-QC.!DF`$B!_R'X
M_O_B/_[_HC^=W/\[8MR]._[_PC_^_X(_N=S>.\/<G#M)]?]+_O]B/(7<8S@]
M]?]+_O]B/(W<8S@Q]?]+_O]B/);<8S@E]?]+>/OC?QWU_TO^_V(\K=QC.!'U
M_TMXZZ-_"?7_2WCSPW\!]?]+>..#?_GT_TO^_V(\S=QC..WT_TO^_V(\:]QC
M..'T_TO^_V(\U]QC.'7T_TMY&V1\#`""07CC@W^1]_]+_O]B/.C<8SA9]/]+
M>1MD?!``@D'^_V(\^MQC.''W_TO^_V(\!=UC.#GT_TMY&V1\)`""07CKHW]5
M]_]+_O^"/'C[XW\FW80X1??_2X``(3A0)0!(_O]B/!7=8S@%]/]+>1MD?-C_
M@D%X\\-_S/__2P`````````!@`0```(`3#R(2D(X````8`B!(H'__PDL9`""
M0*8""'S^_V(\N=QC.!```?BA_R'XN?/_2P``0#D``",L(`""00``(XD```DL
M%`""03``*6DT`"E]?MDI50$`*FD```!@8``A.`B!0I$0``'H````8*8#"'P*
M@6+H(`"`3@```&`*@6+H(`"`3@`````````!@`````(`3#SX24(XI@((?!``
M`?CA_R'XI>O_2Q@`0>B]Z?]+&`!!Z```(RP(`()!``!CZ"``(3@0``'HI@,(
M?"``@$X``````````8`````"`$P\K$E".*8""'P%)`!(@?\A^/[_@C]X&W]\
M*-V<.WCC@W_E\O]+>/OD?WD;?GP0`()!```^B0``"2P4`()`>..#?_'U_TN`
M`"$X_",`2!WI_TL8`$'H```C+.S_@D!X^^-_R>C_2Q@`0>AX&WU\>//#?[GH
M_TL8`$'H%!I]?`(`8SB)Z_]+&`!!Z/[_PCS^_X(\2]V$.'CSQW]X&WU\>-S&
M.'C[Y7_%Z?]+&`!!Z'CKI'^,__]+``````````&`!````@!,/.A(0CBF`@A\
M``!`.9B!2F$````YH($(81TC`$C__P`\_O]"/Q!^`&!BW%H[>!M[?'C30W]J
M`2%\%`I*?10*"'WPCRWI```J^0``(#D```!@"($B.0@`0#F@@>$[F%8)?/__
M0#W`?DIAF%<(?````&`@@4+I````.:"!"&$4"@A]T'Y?^2``0#F85FE],`!`
M.9A6B7U``$`YF%8)?/__0#WP?DIAF%=H?0```#D0`$HYH($(810*"'V85XA]
M````.1``2CF@@0AA%`H(?9A7"'Q0`$`YF%8)?/__(#W8?BEAF$\(?````&!H
M@2+IZ'X_^5'Q_TMY&WY\3`""00``/HD```DL0`""03G^_TMX\\-_->C_2Q@`
M0>AX&WY\```@.9B!*6$4"BE]``!)Z?"/+>EY2DI]```@.>P%@D'IZ/]+&`!!
MZ+']_TO0?K\[>1M^?)0!@D%X\\-__O^"/PGG_TL8`$'H___>.S_=G#ND#V-X
M`0!C.-'I_TL8`$'H>!MY?'@;?7P!`+Z,```%+'`!@D#H?K\["0#=ZP``/BP\
M`()!>//#?YWP_TMY&WY\Z/^"00``/HD```DLW/^"08GQ_TL```,LT/^"07CS
MPW]YY_]+&`!!Z'@;?GRX?I\[```^+!P`@D`)`+SK```]+%`!@D$``#V)```)
M+"`!@D!X\\-__O\"/V'F_TL8`$'H>MP8.W@;?'QXRR-_3>;_2Q@`0>@4&IQ_
M!`2<.[0'G']XXX-_%>G_2Q@`0>C^_^(\_O^"/'C+*']$W><X>,,&?WCSQ7])
MW80X>!M]?$WG_TL8`$'HP`&`.'CKHW^=Z?]+&`!!Z/__`RS0`()`K>;_2Q@`
M0>@``..`$0`'++P`@D$```!@0(`BZ0``N^C^_X(\M`?G?'CKIG]2W80X``!I
MZ!GC_TL8`$'H``#`.V3^_TN%[_]+>1MI?"``@D$``"F)```)+!0`@D%QYO]+
M&`!!Z'D;?GQT_H)`"0!]Z```(RS0_X)`_O_"/SC=WCM<_O]+>.NC?[0'I7QX
MXX1_`@"].YGF_TL8`$'H</[_2WCKHW\I\/]+```#+,#^@D%XZZ-_&>;_2Q@`
M0>AX&WY\I/[_2P``P#N\_O]+('^?.'CKHW\YYO]+&`!!Z````RQX&W=\%`""
M0#A_/X$F!"E5`$`)+"P`@D$```!@0(`BZ0``N^C^_X(\>.NF?XW=A#@``&GH
M.>+_2Q@`0>@@__]+/'_?@PGG_TL8`$'H`!@>?,C_@D`X?S^!_@4I5<`!"2RX
M_X)`>..#?X7G_TL8`$'H>!M^?/[_8CPSW6,X;>[_2WD;9'RT`8)````[ZWC+
M(W]]Y/]+&`!!Z`,``RQX&WQ\B`"!0+0'8WS^_X(\_/]C..#=A#@4&GE\M>C_
M2Q@`0>@```,L9`""0`0`'"P8`()!^_^<.[0'G'^NX#E]+P`)+$@`@D`(`)OK
M```\+#P`@D%XXX-_&>3_2Q@`0>@#`",H*`"!0/S_8SC^_X(\Y=V$.!0:?'Q9
MZ/]+&`!!Z````RP(`()`>..9?^7Y_TL```,L[`&"0```@#AXRR-_\>/_2Q@`
M0>@```,L>!M\?'@;>WS,`8)!`@"@..[_@#C1Y_]+&`!!Z/A_/SL&`*`X>,LD
M?WCC@W\YX?]+&`!!Z/A_/XD```DLR`""0/E_/XE#``DLO`""0/I_/XE!``DL
ML`""0/M_/XE#``DLI`""0/Q_/XE(``DLF`""0/U_/XE%``DLC`""0`(`H#C&
M_X`X>..#?UWG_TL8`$'H*0"@.'C+)']XXX-_R>#_2Q@`0>C^_P(]>,LG?YW>
M"#G^_X(\>,,&?WCKI7_JW80X>//#?T'D_TL8`$'H>.NC?S7A_TL8`$'H>--#
M?WCSQ'_M[_]+>//#?[GY_TN0^_]+``![Z+GS_TMY&WE\2/Z"0$#^_TL``*`X
M``"`.'CC@W___^`ZT>;_2Q@`0>CX?S\[M`=[?R`$]U;]&0!(````8'@;?'QX
MN^5^>,LD?WC;8W\EX/]+&`!!Z````RQP`(%!>-MC?[!_/SN-X?]+&`!!Z'CC
MA']XRR-__O_B/LA_?SM]&P!(````8```@#L_W?<ZKN"Y?'C;8W]XN^1^`0"<
M.P(`>SMQX_]+&`!!Z!0`/"C@_X)````@.?[_`CV=W@@YR'__./!_/YGX_O]+
MM`=E?'C+)']XXX-_\1D`2````&!D__]+_O^"//[_8CPFW80XN=QC..GN_TO^
M_^(__O^"/YW>_SL'WIP[C>#_2Q@`0>C^_X(\>/OH?WC#!G]XZZ5_>!MG?/G=
MA#AX\\-_Z>+_2Q@`0>C``8`X>//#?SGE_TL8`$'H__\#+)3^@D!)XO]+&`!!
MZ```(X$1``DL@/Z"0#7@_TL8`$'H`0#W.GC[Z7^T!^A^>,,&?W@;9WQXZZ5_
M>..$?WCSPW^-XO]+&`!!Z*3__TL``"'H>//#?T`<`$@``````````8`)```"
M`$P\J$%".*8""'P```!@8(`BZ?[_8CP4:BE]G=QC./$;`$B!_R'X```IZ;``
M28FQ`$F9T>K_2P``(RP<`()!```CB3$`"2P0`()``0`CB0``"2P(`()!D?7_
M2P```&#^_X(\8(#BZP,`P#@4:O]_`0"@.!C>A#@``'_H#>#_2Q@`0>AY&WY\
M0`""01``/ND``'_H_O^B/!K>I3@``(GH2=[_2Q@`0>@0`#[I``")Z`P`)(%`
M`"EU$`""00``?^AIW_]+&`!!Z````&#^_X(\8(#BZP,`P#@4:O]_`0"@.!_>
MA#@``'_HH=__2Q@`0>AY&WU\8`""0?[_8CQKW&,X!>K_2WD;97P<`()!$``]
MZ0``?^@``(GHT=W_2Q@`0>@T``!(]>__2Q``/>EY&WY\``!_Z+0`@D$``(GH
M>//%?ZG=_TL8`$'H>//#?QW>_TL8`$'H````8/[_@CQ@@.+K`0"@.!1J_W\A
MWH0X``#?ZWCSPW]5W_]+&`!!Z/[_HCPVWJ4X>!MD?'CSPW]=W?]+&`!!Z```
M/^D``$`Y_O]B/&+<8SBQ`$F97>G_2P```&```",LP(%B^$0`@D````!@N(%B
MZ`7W_TL```!@```C+,"!8O@H`()`_O]B/#S>8S@)W_]+&`!!Z````&"X@4+I
M``")Z```JN@@__]+````8,`!@#C`@6+HP>+_2Q@`0>@!`",Y>!MF?`$`"2@L
M`(%`$0`#+"0`@D$```!@N($BZ<"!HNC^_V(\7=YC.```B>BIWO]+&`!!Z(``
M(3C\&0!(``````````&``P```@!,/$P_0CBF`@A\\/_!^_C_X?MX&W]\$``!
M^)'_(?@Q\O]+V?'_2W@;?GRA]/]+```#+%``@D$``#\L2`""00``/XD```DL
M/`""0?[_@CQX\\-_1-V$.+7>_TL8`$'H`!@^?"``@D!P`"$X>/OC?Q```>CP
M_\'K^/_AZZ8#"'S8Z?]+<``A.'P9`$@``````````8`"```"`$P\M#Y".*8"
M"'PX`,,X`1D`2"'](?CPCRWIJ`(A^0``(#D(`"`YI@,I?2@``3DL-"!]``!&
MZ1``"#D(`,8X(``I>2(`1WGP_RCY(,))>2!&2GDN!"E5>%,I?2C`ZGAX4RE]
M'D+G5'@[*7WX_RCYP/\`0D``(#D@``$YI@,I?7``*.E(`.CH&`!(Z7@Z*7UX
M4BE]"0!(Z7A2*7VD#RIYP@\I>7A+27T@`"EY@``H^=#_`$(``&/I(`"#Z!``
MX^@8`,/H"`"CZ#``X>LX`,'KPBYI>:0N:'EX2PA]*``AZ8+PJG@@``AY@EK_
M/YEY_SN"6MX_@EHI/10R_W^9>2DYF7G>.Q0B*7T4.MY_%$H(?7@RZ7PX*"E]
M>#(I?11*"'UD\*EX>%,I?2``'7D@`"!Y>`+J?#A82GUX.DI]%/I*?<@N'WGB
M+@AY>$/H?X+P?WD40DI]9/!H>7C["'T@`%IY>$(I?2``'WDXZ"E]>`(I?13R
M*7W(+EYYXBY*>7A3RG\44BE]9/"J>X+PO7L@`#MY>.M*?4``H>MX4@A](`!>
M>3C0"'V"6KT_>/H(?9EYO3L4`KU_R"X@>>(N*7D4Z@A]>$L)?!1*"'UD\$E[
M@O!:>R``''EXTRE]>$I`?4@`0>D@`#UY.-@`?'CR`'R"6DH]F7E*.13Z2GT4
M4@!\R"X*>>(N"'EX0TI]%%(`?&3P:GN"\'M[(``:>'C;2GUX4BA]4``AZ2``
M7WDXX`A]>.H(?8):*3V9>2DY%/(I?11*"'W(+@EXXBX`>'@#*7T42@A]9/")
M>X+PG'L@`!MY>.,I?7A*0'U8`$'I(``^>3C0`'QX^@!\@EI*/9EY2CD4ZDI]
M%%(`?,@N"GGB+@AY>$-*?112`'QD\$I[@O!:>R``''AXTTI]>%(H?6``(>D@
M`%UY.-@(?7CR"'V"6BD]F7DI.13Z*7T42@A]R"X)>.(N`'AX`RE]%$H(?63P
M:7N"\'M[(``:>7C;*7UX2D!]:`!!Z2``/WDXX`!\>.H`?():2CV9>4HY%/)*
M?112`'S(+@IYXBX(>7A#2GT44@!\9/"*>X+PG'L@`!MX>.-*?7A2*'UP`"'I
M(`!>>3C0"'UX^@A]@EHI/9EY*3D4ZBE]%$H(?<@N"7CB+@!X>`,I?11*"'UD
M\$E[@O!:>R``''EXTRE]>$I`?7@`0>D@`#UY.-@`?'CR`'R"6DH]F7E*.13Z
M2GT44@!\R"X*>>(N"'EX0TI]%%(`?&3P:GN"\'M[(``:>'C;2GUX4BA]@``A
MZ2``7WDXX`A]>.H(?8):*3V9>2DY%/(I?11*"'W(+@EXXBX`>'@#*7T42@A]
M9/")>X+PG'L@`!MY>.,I?7A*0'V(`$'I(``^>3C0`'QX^@!\@EI*/9EY2CD4
MZDI]%%(`?,@N"GGB+@AY>$-*?112`'QD\$I[@O!:>R``''AXTTI]>%(H?9``
M(>D@`%UY.-@(?7CR"'V"6BD]F7DI.13Z*7T42@A]R"X)>.(N`'AX`RE]%$H(
M?63P:7N"\'M[(``:>7C;*7UX2D!]F`!!Z2``/WDXX`!\>.H`?():2CV9>4HY
M%/)*?112`'S(+@IYXBX(>7A#2GT44@!\9/"*>X+PG'L@`!MX>.-*?7A2*'V@
M`"'I(`!>>3C0"'UX^@A]@EHI/9EY*3D4ZBE]J`"AZQ1*"'W(+@EXXBX`>'@#
M*7V"6KT_%$H(?63P27N"\%I[F7F].WC3*7T@`!QY>$I*?13ZO7\XV$I]R"X?
M>7CR2GWB+@AY>$/H?Q3J2GT40DI]9/!H>X+P>WL@`"!Y>-L(?;``8>L@`%UY
M>$(I?2``'WDXX"E]@EI[/W@"*7V9>7L[%/)[?\@N7GGB+DIY%-HI?7A3RG\4
M4BE]9/"*>X+PG'L@`#MY>.-*?;@`@>MX4@A](`!>>3CH"'V"6IP_>/H(?9EY
MG#L4`IQ_XBX@>2@H*7D4X@A]>`,I?63PH'N"\+U[%$H(?7CK`'QD\'Q[>`))
M?<``0>DXV"E]@O![>WCR*7UXVYQ_@EI*/9EY2CD4^DI]XBX?>112*7TH*`IY
M>/M*?7CB'WP44BE]R`!!Z7A"_W\@`/][(```>(CP/7G:;DH]H>M*.13R2GWB
M+CYY%%+_?R@H*GEX\TI]B/`>>112_W_0`$'IHO`(>7A#WG]X\HA_(`"<>]IN
M2CUX2@A]H>M*.2``"'D4`DI]XB[@>Q1"2GTH*.A[>`,(?:+P*7D40@I\V`!!
MZ7A+O7]XZLE_XBX(>'CZ*7T@`-Y[VFY*/2``*7FAZTHY%.)*?8CP_'L42DI]
M*"@)>'A#*7VB\.A[%$HJ?>``0>EX0YQ_>.*H?^(N/WEX`@A](`"]>]IN2CT@
M``AYH>M*.13R2GV(\!YX%$)*?2@H*'EX^PA]HO``>!1""GWH`$'I>`/>?WCR
M@'_B+A]Y>$H`?"``G'O:;DH](```>*'K2CD4ZDI]B/`]>:+P*7D4`DI]>$N]
M?_``(>DH*`!Y>/L`?!0"ZG]XZLI_VFXI/7A"2GVAZRDY(`!*>13B*7WB+N![
M%%(I?2@HZGMX`TI]B/`<>112"7SX`"'IHO`(>7A#G'\@`-Y[>.*J?^(N"'C:
M;BD]>/I*?:'K*3D@`$IY%/(I?8CP_GL44BE]*"@*>'A#2GT@`+U[%%()?0`!
M(>FB\.I[>%/>?^(N'WEX\HI_(`"<>]IN*3UX`DI]H>LI.2``2GD4ZBE]B/`=
M>!12*7TH*`IY>/M*?:+P`'@44DE]"`$AZ7@#O7]XZL!_XBY?>7A"`'P@`-Y[
MVFXI/2```'BAZRDY%.(I?10"*7TH*$!Y>/L`?(CP'WD4`@E\$`$AZ:+P"'EX
M0_]_>/JH?R``O7O:;BD]>%((?:'K*3D@``AY%/(I?>(N'G@40BE]*"@(>'CS
M"'V(\%YY%$()?1@!(>FB\$IY>%/>?WCRZG\@`/][VFXI/7@"2GVAZRDY(`!*
M>13J*7WB+AUY%%(I?2@H"GEXZTI]B/`=>!1227T@`2'IHO``>'@#O7]XZL!_
M(`#>>]IN*3UX0@!\H>LI.2```'@4^BE]XBY?>10"*7TH*$!Y>/L`?(CP'WD4
M`@E\*`$AZ:+P"'EX0_]_>/JH?R``O7O:;BD]>%((?:'K*3D@``AY%/(I?>(N
M'G@40BE]*"@(>'CS"'V(\%YY%$()?3`!(>FB\$IY>%/>?WCRZG\@`/][VFXI
M/7@"2GVAZRDY(`!*>13J*7WB+AUY%%(I?2@H"GEXZTI]B/`=>!1227TX`2'I
MHO``>'@#O7]XZL!_(`#>>]IN*3UX0@!\H>LI.2```'@4^BE]XBY?>10"*7TH
M*$!Y>/L`?(CP'WD4`@E\0`$AZ:+P"'EX0_]_B/`;>'CZJ'\@`+U[VFXI/7A2
M"'VAZRDY(``(>13R*7WB+AYX%$(I?2@H"'AX\PA]B/!>>11""7U(`2'IHO!*
M>7A3WG]X\NI_(`#_>]IN*3UX`DI]H>LI.2``2GD4ZBE]XBX=>112*7TH*`IY
M>.M*?:+P`'@44DE]4`$AZ7@#>W]XVL!_(`#>>WA"`'R(\$QYVFXI/2```'BA
MZRDY%/HI?>(N7WD4`BE]*"A`>7C[`'R(\!]Y%`*)?U@!(>FB\`AY>$/_?^(N
MB'O:;BD]H>L).'CZ:7]X4BE]%/(`?"``*7FB\$IY%$H`?,@NB7MX0RE]>%.,
M?11*`'Q@`2'I(`![>R``'7B(\(A[(`">>=IN23UX8NE_>.(I?:'K2CD4VDI]
M(``I>6@!8>L42DI]R"X)>.(N`'@@`/][>`,I?11*2GVB\(E[>$L(?1N/(#W<
MO"EA(``<>2``*7EX0X!]%-II?SC@C'TXZ`!\%/K[?WAC`'P@`%IY%/H`?,@N
M7WGB+DIY>%/J?V3POWN"\+U[%%)`?7CK_W\@`$QY>/L(?3C@X'\XT`A](`#]
M>W@#"'UP`0'H%`()?!3R`'P4`@A]R"Y`>>(N2GEX4PI\%%((?63P2GN"\%I[
M(``;>7C32GT@`%YY>%/@?SA@`'PX\/]_>/L`?'@!X>L4^NE_%.+_?Q3Z`'S(
M+A]YXBX(>7A#Z']D\)]Y@O",>11"`'QX8_]_(``:>'C[2'TX\.I_.-@(?2``
M_'MX4PA]@`%!Z11227T4ZDI]%%((?<@N"GCB+@!X>`-*?112"'UD\&I[@O![
M>R``#'EXVTI](`!=>7A3X'\XT`!\..C_?WC[`'R(`>'K%/KI?Q3R_W\4^@!\
MR"X?>>(N"'EX0^A_9/!?>X+P6GL40@!\>-/_?R``&WAX^TA]..CJ?SA@"'T@
M`/Y[>%,(?9`!0>D44DE]%.)*?112"'W(+@IXXBX`>'@#2GT44@A]9/"*>8+P
MC'D@`!IY>&-*?2``7'EX4^!_.-@`?#C@_W]X^P!\F`'AZQ3ZZ7\4ZO]_%/H`
M?,@N'WGB+@AY>$/H?V3P?WN"\'M[%$(`?'C;_W\@``QX>/M(?3C@ZG\XT`A]
M(`#]>WA3"'V@`4'I%%))?13R2GT44@A]R"X*>.(N`'AX`TI]%%((?63P2GN"
M\%I[(``;>7C32GT@`%YY>%/@?SA@`'PX\/]_>/L`?*@!X>L4^NE_%.+_?Q3Z
M`'S(+A]YXBX(>7A#Z']D\)]Y@O",>11"`'QX8_]_(``:>'C[2'TX\.I_.-@(
M?2``_'MX4PA]L`%!Z11227T4ZDI]%%((?<@N"GCB+@!X>`-*?112"'UD\&I[
M@O![>R``#'EXVTI](`!=>7A3X'\XT`!\..C_?WC[`'RX`>'K%/KI?Q3R_W\4
M^@!\R"X?>>(N"'EX0^A_9/!?>X+P6GL40@!\>-/_?R``&WAX^TA]..CJ?SA@
M"'T@`/Y[>%,(?<`!0>D44DE]%.)*?112"'W(+@IXXBX`>'@#2GT44@A]9/"*
M>8+PC'D@`!IY>&-*?2``7'EX4^!_.-@`?#C@_W]X^P!\R`'AZQ3ZZ7\4ZO]_
M%/H`?,@N'WGB+@AY>$/H?V3P?WN"\'M[%$(`?'C;_W\@``QX>/M(?3C@ZG\X
MT`A](`#]>WA3"'W0`4'I%%))?13R2GT44@A]R"X*>.(N`'AX`TI]%%((?63P
M2GN"\%I[(``;>7C32GT@`%YY>%/@?SA@`'PX\/]_>/L`?-@!X>L4^NE_%.+_
M?Q3Z`'S(+A]YXBX(>7A#Z']D\)]Y@O",>11"`'QX8_]_(``:>'C[2'TX\.I_
M.-@(?2``_'MX4PA]X`%!Z11227T4ZDI]%%((?<@N"GCB+@!X>`-*?112"'UD
M\&I[@O![>R``#'EXVTI](`!=>7A3X'\XT`!\..C_?WC[`'SH`>'K%/KI?Q3R
M_W]D\%Y[@O!:>Q3Z`'QXT]Y_R"X?>>(N"'EX\TI]>$/H?SA@2GT40@!]..C`
M?W@#2GWP`0'H(``;>2``WWL4`@E\%.(`?!0"2GW(+@!YXBX(>7A#"'P40DI]
M9/"(>8+PC'D@`%QY>&,(?2``#'EX0\!_.-@`?#A@WG]X\P!\^`'!ZQ3RR7\4
MZMY_%/(`?.(N7GDH*$IY>/-*?112`'QD\&I[@O![>WC;2GUX4PA].&!=?3C@
M"'T@`%YY>.L(?0`"H>L4ZBE]%/HI?>(N'W@42@A]*"@)>'C[*7UD\)][%$H(
M?8+PB7MX2_Q_"`+AZV+*(#W6P2EA>.)*?2``*7EX`DI]%/KI?R``2GD48O]_
MXBX=>13Z2GTH*!]Y>.O_?XCP'7@4^DI]HO``>!`"X>MX`[U_>.J`?R``G'MX
M0@!\%/KI?Q3R_W\@``!XXBY>>13Z`'PH*%]Y>//_?XCP'GFB\`AY%/H`?'A#
MWG\8`@'I>/*_?R``O7MX4O]_%$()?2``_WL4X@A]XBX<>!3Z"'TH*!]X>./_
M?Q3Z"'V(\%]YHO!*>>(N''EX4_]_(`)!Z11227T4ZDI]>/K=?W@"O7\@`-Y[
M(`"]>Q3J2GTH*!UY>..]?Q3J2GV(\!UXHO``>.(N7'EX`[U_*`(!Z!0""7P4
M\@!\>.K^?WA"WG\@`/][(`#>>Q3R`'PH*%YY>./>?Q3R`'R(\!YYHO`(>>(N
M''AX0]Y_,`(!Z11""7T4^@A]>/*_?WA2_W\@`+U[(`#_>Q3Z"'TH*!]X>./_
M?Q3Z"'V(\%]YHO!*>>(N''EX4_]_.`)!Z11227T4ZDI]>/K=?W@"O7\@`-Y[
M(`"]>Q3J2GTH*!UY>..]?Q3J2GV(\!UXHO``>.(N7'EX`[U_0`(!Z!0""7P4
M\@!\>.K^?WA"WG\@`/][(`#>>Q3R`'PH*%YY>./>?Q3R`'R(\!YYHO`(>>(N
M''AX0]Y_2`(!Z11""7T4^@A]>/*_?WA2_W\@`+U[(`#_>Q3Z"'TH*!]X>./_
M?Q3Z"'V(\%]YHO!*>>(N''EX4_]_4`)!Z11227T4ZDI]>/K=?W@"O7\@`-Y[
M(`"]>Q3J2GTH*!UY>..]?Q3J2GV(\!UXHO``>.(N7'EX`[U_6`(!Z!0""7P4
M\@!\>.K^?WA"WG\@`/][(`#>>Q3R`'PH*%YY>./>?Q3R`'R(\!YYHO`(>>(N
M''AX0]Y_8`(!Z11""7T4^@A]>/*_?WA2_W\@`+U[(`#_>Q3Z"'TH*!]X>./_
M?Q3Z"'V(\%]YHO!*>>(N''EX4_]_:`)!Z11227T4ZDI]>/K=?W@"O7\@`-Y[
M(`"]>Q3J2GTH*!UY>..]?Q3J2GV(\!UXHO``>.(N7'EX`[U_<`(!Z!0""7P4
M\@!\>.K^?WA"WG\@`/][(`#>>Q3R`'PH*%YY>./>?Q3R`'R(\!YYHO`(>>(N
M''AX0]Y_>`(!Z11""7T4^@A]>/*_?WA2_W\@`+U[(`#_>Q3Z"'TH*!]X>./_
M?Q3Z"'V(\%]YHO!*>>(N''EX4_]_@`)!Z11227T4ZDI]>/K=?W@"O7\@`-Y[
M(`"]>Q3J2GTH*!UY>..]?XCP''BB\`!X%.I*?7@#G'^(`@'HXBY=>10""7P4
M\@!\>.+^?WA"WG\@`/][(`#>>Q3R`'PH*%YY>.O>?XCP'7FB\`AY%/(`?'A#
MO7^0`@'IXBX>>!1""7T4^@A]>.J??WA2_W\@`)Q[(`#_>Q3Z"'TH*!]X>//_
M?XCP7GFB\$IY%/KH?WA3WG^8`D'I>/*H?R``O7MX`@A]%%))?2``"'D4XDI]
MXB[\>Q1"2GW(+NA[>.,(?11"2GV(\`AXHO``>'@#"'V@`@'H%`(I?>(N0'D4
M6BE]>$++?WCZ:WT4ZBE](`!K>10R"'T46BE]R"Y+>10J2GUX`VM](`!*>11:
M*7T@`"EYHO#E>P@`0_F(\.I[(``(>7@K2GT``"/Y%"(^?10Z2GT@`"EY&``#
M^2``2GD@`"/Y$`!#^:@"0>GPCRWI>4I*?0``(#D,`()!A<K_2Q@`0>C@`B$X
MS`,`2``````````!@`8```(`3#PH*4(XI@((?(``8#@0``'XX?\A^''+_TL8
M`$'H16=`/2``(3@!(TIA``!#^<WO0#V)JTIA(`!*>0@`0_FZF$`]_MQ*82``
M2GD0`$/Y,A!`/7942F$8`$/YTL-`/?#A2F$@`$IY(`!#^0``0#EX`$.1*`!#
M^3``0_D0``'HI@,(?"``@$X``````````8`````"`$P\E"A".*8""'PD'ZEX
MW0(`2*'_(?AX&W]\>".9?'@KOGPH`$/I%%(I?2``*7E`2"I\$`"!0#``0^D!
M`$HY,`!#^7@`?X`H`#_Y,``_Z4(?RGLX`)\[```#+!12*7TP`#_Y6`""04``
MHR,`\!U\"`"!0'CSW7^T![M_M`=C?'C;97]XRR1_%!I\?`G%_TL8`$'H>``_
M@11*/7U```DL>``_D40`@D!0\+U_>/OC?[0'OG\4VCE_,>G_2Q``H#L@`&`[
M,`!`.S\`'BPD`(%!>//%?WC+)']XXX-_N<3_2Q@`0>AX`-^38``A.#@"`$B8
MSD!]F.YY?<#_WCMX^^-_F-Z9?9C6&7RT!]Y_0``Y.YCG0'V8[WQ]F-^<?9C7
M''S)Z/]+I/__2P`````````!@`<```(`3#Q@)T(XI@((?"@`)#F`_T`YK0$`
M2+'_(?@X`*0[>!M^?'@CGWPL3(!_,``D.2Q,8'\H`"3IONXI50$`J3BT!RE]
M.``%++0'HWRN25U]%!I]?#0!@4!``*4@``"`.+0'I7Q]Q_]+&`!!Z'C[XW]%
MZ/]+.`"@.```@#AXZZ-_8<?_2Q@`0>AP`'^3=`"?DWC[XW\AZ/]+```_Z7C[
MXW\"1BEY```^F0``/^D"A"EY`0`^F0``/^D"PBEY`@`^F0``/^D#`#Z9"``_
MZ0)&*7D$`#Z9"``_Z0*$*7D%`#Z9"``_Z0+"*7D&`#Z9"``_Z0<`/ID0`#_I
M`D8I>0@`/ID0`#_I`H0I>0D`/ID0`#_I`L(I>0H`/ID0`#_I"P`^F1@`/^D"
M1BEY#``^F1@`/^D"A"EY#0`^F1@`/^D"PBEY#@`^F1@`/^D/`#Z9(``_Z0)&
M*7D0`#Z9(``_Z0*$*7D1`#Z9(``_Z0+"*7D2`#Z9(``_Z1,`/IFIP_]+&`!!
MZ%``(3AT``!(.`"E(```@#BT!Z5\[/[_2P`````````!@`4``*#_@?JH_Z'Z
ML/_!^KC_X?K`_P'[R/\A^]#_0?O8_V'[X/^!^^C_H?OP_\'[^/_A^Q```?@@
M`(!.H/^!ZJC_H>JP_\'JN/_AZL#_`>O(_R'KT/]!Z]C_8>O@_X'K$``!Z.C_
MH>NF`PA\\/_!Z_C_X>L@`(!.\/_!ZQ```>CX_^'KI@,(?"``@$X```!@0*,!
M``````"F`@A\!0"?0J8":'VF`PA\\/\+Z%!@BWT46F!]U/\,.```B^F"\`!X
MI@.)?0@`:^D@!(!.S/__2\C__TO$__]+P/__2[S__TNX__]+M/__2[#__TNL
M__]+J/__2Z3__TN@__]+G/__2YC__TN4__]+D/__2XS__TN(__]+A/__2X#_
M_TM\__]+>/__2W3__TMP__]+;/__2VC__TMD__]+8/__2US__TM8__]+5/__
M2U#__TM,__]+2/__2T3__TM`__]+//__2SC__TLT__]+,/__2RS__TLH__]+
M)/__2R#__TL<__]+&/__2Q3__TL0__]+#/__2PC__TL$__]+`/__2_S^_TOX
M_O]+]/[_2_#^_TOL_O]+Z/[_2P(`3#P,)$(XI@((?!```?CA_R'X(``A.!``
M`>BF`PA\(`"`3BXN`"5S+R5S`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E
M<@!);G1E<FYA;',Z.E!!4CHZ0D]/5`!E>&4`+W!R;V,O)6DO)7,`4$%27U1%
M35``4$%27U!23T=.04U%`#H`+P!015),-4Q)0@!015),3$E"`%!%4DPU3U!4
M`%!%4DQ)3P!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.
M`%!!4E]$14)51P!005)?0T%#2$4`4$%27T=,3T)!3%]$14)51P!005)?1TQ/
M0D%,7U1-4$1)4@!005)?5$U01$E2`%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/
M0D%,7T-,14%.`#$`3$1?3$E"4D%265]0051(`%-94U1%30`E,#)X`'!A<BT`
M)7,E<R5S)7,`)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y
M("5S(&9A:6QE9"`H97)R;F\])6DI"@`E<SH@<')I=F%T92!S=6)D:7)E8W1O
M<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y
M;W5R(&]P97)A=&EO;BD*`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E<P`E<R5S
M=&5M<"TE=25S`"5S)7-T96UP+25U+25U)7,`&`!P97)L`#``4$%2.CI086-K
M97(Z.E9%4E-)3TX`,2XP-38`56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E
M8W1O<GD`)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T
M;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@`M90`M+0!54T52`%5315).04U%
M`%1%35!$25(`5$U0`"]T;7``979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M
M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M
M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@)$9)
M3$5?;V9F<V5T7W-I>F4L("1#04-(15]M87)K97(L("1C86-H95]N86UE7W-I
M>F4I.PI"14=)3B!["B1005)?34%'24,@/2`B7&Y005(N<&U<;B(["B1&24Q%
M7V]F9G-E=%]S:7IE(#T@-#L@("`C('!A8VLH(DXB*0HD8V%C:&5?;6%R:V5R
M(#T@(EPP0T%#2$4B.PHD8V%C:&5?;F%M95]S:7IE(#T@-#`["GT*<W5B(&9I
M;F1?<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I>F4@
M/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@+7,@)&9H.PIM>2`D
M<&]S(#T@)'-I>F4@+2`D<VEZ92`E("1C:'5N:U]S:7IE.R`@("`@(",@3D]4
M13H@)'!O<R!I<R!A(&UU;'1I<&QE(&]F("1C:'5N:U]S:7IE"G=H:6QE("@D
M<&]S(#X](#`I('L*<V5E:R`D9F@L("1P;W,L(#`["G)E860@)&9H+"`D8G5F
M+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D
M:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@>PHD<&]S("L]
M("1I.PIR971U<FX@)'!O<SL*?0HD<&]S("T]("1C:'5N:U]S:7IE.PI]"G)E
M='5R;B`M,3L*?0IM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE
M+"`E36]D=6QE0V%C:&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2![
M"G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*
M<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA
M;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<5M296UO=FEN9R!F:6QE
M<R!I;B`B)'!A<E]T96UP(ETI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B
M('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD
M:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7
M:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]
M/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H
M)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIM
M>2`D9FEL96YA;64@/2`D=&UP+3YF:6QE;F%M93L*<')I;G0@)'1M<"`\/"(N
M+BXB.PIX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P
M87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K
M"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<D9FEL96YA
M;64G"BXN+@IC;&]S92`D=&UP.PIC:&UO9"`P-S`P+"`D9FEL96YA;64["FUY
M("1C;60@/2`B)&9I;&5N86UE(#XO9&5V+VYU;&P@,CXF,2`F(CL*<WES=&5M
M*"1C;60I.PIO=71S*'%Q6U-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O
M('!E<F9O<FT@8VQE86YU<#H@)&9I;&5N86UE72D["GT*?2!]"D)%1TE.('L*
M26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z
M.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T
M(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)7-Y<R`]("@*<&%T:%]S97`@("`@
M/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@
M(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@
M.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@
M)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*;W5T<RAQ<5M<)'!R
M;V=N86UE(#T@(B1P<F]G;F%M92)=*3L*7W-E=%]P87)?=&5M<"@I.PIO=71S
M*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2)=*3L*;7D@
M*"1S=&%R=%]P;W,L("1D871A7W!O<RD["DU!1TE#.B!["FQO8V%L("1324=[
M7U]705).7U]](#T@<W5B('M].PIU;FQE<W,@*&]P96X@7T9(+"`G/#IR87<G
M+"`D<')O9VYA;64I('L*;W5T<RAQ<5M#86XG="!R96%D(&9R;VT@9FEL92`B
M)'!R;V=N86UE(ETI.R`@(R!D;VXG="!U<V4@)"$@:&5R92!A<R!I="!R97%U
M:7)E<R!%<G)N;RYP;0IL87-T($U!1TE#.PI]"FUY("1M86=I8U]P;W,@/2!F
M:6YD7W!A<E]M86=I8R@J7T9(*3L*:68@*"1M86=I8U]P;W,@/"`P*2!["F]U
M=',H<7%;0V%N)W0@9FEN9"!M86=I8R!S=')I;F<@(B1005)?34%'24,B(&EN
M(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0SL*?0IO=71S*")&;W5N
M9"!005(@;6%G:6,@870@<&]S:71I;VX@)&UA9VEC7W!O<R(I.PIS965K(%]&
M2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE+"`P.PIR96%D(%]&
M2"P@)&)U9BP@)$9)3$5?;V9F<V5T7W-I>F4["FUY("1O9F9S970@/2!U;G!A
M8VLH(DXB+"`D8G5F*3L*;W5T<R@B3V9F<V5T(&9R;VT@<W1A<G0@;V8@1DE,
M17,@:7,@)&]F9G-E="(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%
M7V]F9G-E=%]S:7IE("T@)&]F9G-E="P@,#L*)&1A=&%?<&]S(#T@=&5L;"!?
M1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@
M("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B
M"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*
M<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA
M;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B
M+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX
M?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@
M*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B
M=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@
M*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI
M)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B
M=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@
M/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE
M?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H
M;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE
M;F%M92`](%]S879E7V%S*"(D8F%S96YA;64D97AT(BP@)&)U9BP@,#<U-2D[
M"F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PI]"F5L<V4@>PHD36]D=6QE
M0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C
M+`IN86UE(#T^("1F=6QL;F%M92P*?3L*)')E<75I<F5?;&ES='LD9G5L;&YA
M;65]*RL["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS
M=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@
M)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2`D36]D=6QE0V%C:&5[
M)&UO9'5L97T["G)E='5R;B!U;FQE<W,@)&EN9F\["F1E;&5T92`D<F5Q=6ER
M95]L:7-T>R1M;V1U;&5].PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN
M9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H
M)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP
M9FEL92!O<B!D:64@(D-A;B=T(&-R96%T92!T96UP(&9I;&4Z("0A(CL*)&9H
M+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN9F\M/GMB=69]*3L*)&9H+3YS
M965K*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@
M/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*
M)&EN9F\M/GMF:6QE?2`]("1F:6QE;F%M93L*;W!E;B!M>2`D9F@L("<\.G)A
M=R<L("1F:6QE;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&5N86UE
M(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL
M960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U;&4A(CL*?2P@0$E.0RD["G)E
M<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#
M87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI
M;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;
M,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^
M("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR
M97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S
M<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE
M=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"G5N;&5S<R`H)&)U9B!E
M<2`B4$M<,#`S7#`P-"(I('L*;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@
M1DE,12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)
M0R`["GT*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@
M("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L
M("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM0
M05)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C
M=7)I='D@<')O8FQE;2D*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E
M<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]
M('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN
M<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H
M0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'
M5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@
M>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI
M;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=
M*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O
M7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B
M.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R
M.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D
M,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@
M)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2![
M"B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F
M:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R
M(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D
M,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q
M?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q
M=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S
M($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE
M>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D
M;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI:
M:7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!
M4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F
M:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL
M92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]
M($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L
M92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I
M92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*;7D@
M)6UE=&%?<&%R(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP
M+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD
M+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ
M72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@
M;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A
M<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@
M-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B
M=68@97$@(E!+7#`P,UPP,#0B.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D
M;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE
M.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE
M.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F
M:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L
M(#`["FUY("1L;V%D97(["FEF("AD969I;F5D("1D871A7W!O<RD@>PIR96%D
M(%]&2"P@)&QO861E<BP@)&1A=&%?<&]S.PI](&5L<V4@>PIL;V-A;"`D+R`]
M('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"
M051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I
M<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R
M:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*:68@*"1M971A7W!A<GMC;&5A
M;GTI('L*;7D@)'!A<E]C;&5A;B`]("(],2(["FUY("1P87-S7W!A<E]C;&5A
M;B`]('5C(")?7W!A<W-?<&%R7V-L96%N7U\B.PHD;&]A9&5R(#U^('-[*#\\
M/21[<&%S<U]P87)?8VQE86Y]*2@@*RE]"GLD<&%R7V-L96%N("X@*"(@(B!X
M("AL96YG=&@H)#$I("T@;&5N9W1H*"1P87)?8VQE86XI*2E]96<["GT*)&9H
M+3YP<FEN="@D;&]A9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D
M97(@=&\@(B1O=70B.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2
M.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET
M7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A
M+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@
M;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N
M9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S
M?"\D?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F
M;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.
M0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@
M("`@("`@(R!86%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF
M;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE
M+"`D;F%M92D["FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&
M=6QL0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F
M8RD["GT*96QS92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME
M>2`]?B!M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@
M*"1K97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>
M+UTK+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI
M('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M
M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D
M,2D["FQA<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*
M;F5X="!I9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE
M*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN
M=&8H<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL
M92T^>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I
M;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A
M;"`D+R`]('5N9&5F.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@
M9&EE('%Q6T-A;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD
M=&@^.PIC;&]S92`D=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH
M7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]6
M15)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2
M.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L
M("1F:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG
M+"!L96YG=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H
M:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C
M:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q
M6T5R<F]R('=R:71I;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z("0A73L*
M;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D>FEP*2![
M"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP
M.CI!6E]/2PIO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B
M)&]U=")=.PI]"B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P
M+"`D8V%C:&5?;F%M95]S:7IE.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D
M;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T>"`]($1I9V5S=#HZ
M4TA!+3YN97<H,2D["F]P96X@;7D@)'1H+"`B/#IR87<B+"`D;W5T.PHD8W1X
M+3YA9&1F:6QE*"1T:"D["F-L;W-E("1T:#L*)&-A8VAE7VYA;64@/2`D8W1X
M+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@D8V%C:&5?
M;F%M95]S:7IE("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@
M+CT@)&-A8VAE7VUA<FME<CL*;7D@)&]F9G-E="`]("1F:"T^=&5L;"`K(&QE
M;F=T:"@D8V%C:&5?;F%M92D@+2!L96YG=&@H)&QO861E<BD["B1F:"T^<')I
M;G0H)&-A8VAE7VYA;64L"G!A8VLH)TXG+"`D;V9F<V5T*2P*)%!!4E]-04=)
M0RD*)B8@)&9H+3YC;&]S90IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!T<F%I
M;&5R(&]F("(D;W5T(CH@)"%=.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]
M"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N
M86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z
M.EII<#L*?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@
M24\Z.DAA;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D
M:64@<7%;9F1O<&5N*"D@9F%I;&5D.B`D(5T["D%R8VAI=F4Z.EII<#HZ<V5T
M0VAU;FM3:7IE*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE
M=SL**"1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@
M/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@<F5A
M9&EN9R!Z:7`@87)C:&EV92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ
M<V5T0VAU;FM3:7IE*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L
M("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PIO=71S
M*")%>'1R86-T:6YG('II<"XN+B(I.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]4
M14U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C
M:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M
M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^
M9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_
M<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N
M9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X
M=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^
M8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M
M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D
M4VEZ92@I*2!["F]U=',H<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN
M8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B72D["GT@96QS
M92!["F]U=',H<7%;17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E
M<W1?;F%M92(N+BY=*3L**"1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D
M9&5S=%]N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q
M<5M%<G)O<B!E>'1R86-T:6YG('II<"!M96UB97(@=&\@(B1D97-T7VYA;64B
M73L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*
M?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*
M9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A
M<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G
M<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD
M14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!
M4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q
M=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E
M>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ
M)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D
M<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R
M<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U
M:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I
M8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#
M87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U
M:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER
M92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P
M96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E
M($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E
M<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S
M=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U
M:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`[
M"G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A
M='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I
M<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V
M86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@
M<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q
M=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![
M(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E
M9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H
M+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@
M)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@
M5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@
M>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@
M+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W
M=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F
M:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS
M,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E
M<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%
M4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*;7D@)'-T;7!D
M:7(@/2`B)'!A=&@D<WES>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S
M97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FUY("1C86-H95]D:7([
M"FEF("@D14Y6>U!!4E]#3$5!3GTI('L*)&-A8VAE7V1I<B`](")T96UP+20D
M(CL*?0IE;'-E('L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M92!O
M<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PII9B`H*&UY
M("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@D9F@I*2`^/2`P*2!["G-E
M96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG
M=&@H)&-A8VAE7VUA<FME<BDL(#`["FUY("1B=68["G)E860@)&9H+"`D8G5F
M+"!L96YG=&@H)&-A8VAE7VUA<FME<BD["FEF("@D8G5F(&5Q("1C86-H95]M
M87)K97(I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?
M<VEZ90HM(&QE;F=T:"@D8V%C:&5?;6%R:V5R*0HM("1C86-H95]N86UE7W-I
M>F4L(#`["G)E860@)&9H+"`D8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD8G5F
M(#U^(',O7#`O+V<["B1C86-H95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*?0IC
M;&]S92`D9F@["GT*:68@*"$D8V%C:&5?9&ER*2!["B1C86-H95]D:7(@/2`B
M=&5M<"TD)"(["B1%3E9[4$%27T-,14%.?2`](#$["GT*)'-T;7!D:7(@+CT@
M(B1S>7-[7V1E;&EM?21C86-H95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@,#<U
M-3L*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R7W1E
M;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@
M/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E
M;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D
M;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]
M("(D9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@
M)'1E;7!N86UE*0HF)B`H<')I;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E
M("1F:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@(B1T96UP;F%M92(Z("0A
M73L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR
M96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA
M;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@
M>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%2
M7U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R
M;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D
M<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]
M('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E
M;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E
M>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M
M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*
M:68@*"US("(D<')O9VYA;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@
M)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI
M="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF
M(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]4
M14U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N
M86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL
M(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?
M97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA
M;64B*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B
M.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@
M)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES
M>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P
M<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@
M/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_
M(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G
M;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES
M>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*
M<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$
M?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!
M3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"
M54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[(E!!4E\D7R)]
M.PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.
M5GLB4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@97AI<W1S
M("1%3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II9B`H)$5.5GM005)?5$5-4'TI
M('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0I]"G-U8B!O=71S('L*<F5T
M=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?
M7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@
M>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA
M<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB
M97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD
M;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H
M:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A
M<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B
M)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE
M<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I
M(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D
M0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I
M(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE
M("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`<&5R;'AS
M:2YC`````1L#.]@````:````/(?__Y@$``#`B___"`$``)",__]``0``\(S_
M_V`!``"4C?__B`$``$".__^P`0``O(___^@!``#8D?__)`(``#B2__]$`@``
MI)+__V@"``"$D___E`(``)R3__^H`@``Y)7___@"```XEO__'`,``'27__](
M`P``M)C__WP#``!$F?__G`,``)"9__^\`P``5)K___`#``"4H?__-`0``/"C
M__]D!```B*3__[P$```4NO__]`0``*BZ__\4!0``W+O__U`%```4OO__\```
M`!```````````7I2``1X00$;#`$`%````!@````<O?__'`$```!""4$`0@9!
M-````#````"PBO__T`````!#"4$`09H&FP6<!)T#G@*?`1%!?D(.4$L*#@!"
MW][=W-O:!D$+```<````:````$B+__]@`````$4.<!%!?DT.`$(&00```"0`
M``"(````B(O__Z0`````10E!`)X"GP%##H`!$4%^70X`0=_>!D$D````L```
M``2,__^L`````$0)00"?`4,.T`$107Y@#@!!WP9!````-````-@```"(C/__
M?`$```!#"4$`09H&FP6<!)T#G@*?`1%!?D$.L`("5@X`0=_>W=S;V@9!```X
M````$`$``,R-__\<`@```$,)00!!F0>:!IL%G`2=`YX"GP$107Y!#K`!`GX.
M`$'?WMW<V]K9!D$````<````3`$``*R/__]@`````$X.(!%!?D0.`$(&00``
M`"````!L`0``[(___VP`````1`E!`)\!10XP$4%^3@X`0=\&02@```"0`0``
M-)#__^``````0PE!`$&=`YX"GP$107Y!#J!!;@X`0M_>W09!$````+P!``#H
MD/__&`````````!,````T`$``.R0__](`@```$4)00`12']!E`R5"Y8*EPF8
M")D'F@:;!9P$G0.>`I\!$4%^00[@(@*$#@!$W][=W-O:V=C7UM74!D$&2```
M`"`````@`@``Y)+__U0`````10E!`)\!0PXP$4%^20X`0=\&02@```!$`@``
M%)/__SP!````10E!`)X"GP%##L`@$4%^`D,.`$'?W@9!````,````'`"```D
ME/__0`$```!%"4$`09P$G0.>`I\!$4%^00Z``7X*#@!!W][=W`9!"P```!P`
M``"D`@``,)7__Y``````2PY@$4%^30X`1`9!````'````,0"``"@E?__3```
M``!%#B`107Y(#@!"!D$````P````Y`(``,R5___$`````$,)00!!G`2=`YX"
MGP$107Y!#H`!3@H.`$'?WMW<!D$+````0````!@#``!<EO__0`<```!'"4$`
M09<)F`B9!YH&FP6<!)T#G@*?`1%!?D<.\(,"`[P!#@!"W][=W-O:V=C7!D$`
M```L````7`,``%B=__]<`@```$@)00!!G0.>`I\!$4%^00Z``0*)#@!!W][=
M!D$````P````C`,``(2?__^8`````$4)00">`I\!0PYP$4%^4PH.`$4&0=_>
M00M!#@!!W]X&00``(````,`#``"<@O__/`(```!&#I`!$4%^GP$"@`H.`$+?
M!D$+-````.0#``#$G___C!4```!$"4$`09H&FP6<!)T#G@*?`1%!?D$.X`4#
M604.`$'?WMW<V]H&00`<````'`0``!BU__^4`````$8.(!%!?D0.`%<&00``
M`#@````\!```C+7__S0!````1`E!`$&9!YH&FP6<!)T#G@*?`1%!?D$.8'4*
M#@!!W][=W-O:V09!"P```#````!X!```A+;__Z0!````10E!`$&;!9P$G0.>
M`I\!$4%^00Y0`EH*#@!!W][=W-L&00L`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````,"<```````"@)@````````$`````````V@(````````!
M`````````.4"````````#P````````!)!0````````P`````````F!L`````
M```-`````````/1:````````&0`````````0^P$``````!L`````````"```
M```````:`````````!C[`0``````'``````````(`````````/7^_V\`````
M(`(````````%`````````&@.````````!@````````#X`@````````H`````
M````9P4````````+`````````!@`````````%0````````````````````,`
M````````(/T!```````"`````````'`%````````%``````````'````````
M`!<`````````*!8```````````!P`````.Q9`````````P``<```````````
M``````<`````````T!,````````(`````````%@"````````"0`````````8
M`````````!@```````````````````#[__]O``````$```@`````^?__;P``
M```-````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'\"````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````@``````_____P````"^70```````!E;````
M``````````````#Z6P```````/-;````````LET````````07````````+I=
M``````````````````"D70```````*E=``````````````````##70``````
M`$=#0SH@*$%L<&EN92`Q,BXR+C%?9VET,C`R,C`Y,C0M<C0I(#$R+C(N,2`R
M,#(R,#DR-```+G-H<W1R=&%B`"YI;G1E<G``+F=N=2YH87-H`"YD>6YS>6T`
M+F1Y;G-T<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YI;FET`"YT97AT`"YF:6YI
M`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+FEN:71?87)R87D`
M+F9I;FE?87)R87D`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT
M````````````````````````````````````````````````````````````
M````````````````````````````````````"P````$````"```````````"
M``````````(````````>`````````````````````0``````````````````
M`!,```#V__]O`@`````````@`@```````"`"````````V``````````#````
M``````@````````````````````=````"P````(`````````^`(```````#X
M`@```````'`+````````!````!L````(`````````!@`````````)0````,`
M```"`````````&@.````````:`X```````!G!0```````````````````0``
M`````````````````"T````$`````@````````#0$P```````-`3````````
M6`(````````#``````````@`````````&``````````W````!````$(`````
M````*!8````````H%@```````'`%`````````P```!`````(`````````!@`
M````````00````$````&`````````)@;````````F!L````````D````````
M````````````!````````````````````$<````!````!@````````#`&P``
M`````,`;````````-#\``````````````````"````````````````````!-
M`````0````8`````````]%H```````#T6@```````"0`````````````````
M```$````````````````````4P````$````"`````````!A;````````&%L`
M``````"J0```````````````````"````````````````````%L````!````
M`@````````#$FP```````,2;````````W`````````````````````0`````
M``````````````!I`````0````(`````````H)P```````"@G````````*P$
M```````````````````$````````````````````<P````X````#````````
M`!#[`0``````$/L````````(````````````````````"``````````(````
M`````'\````/`````P`````````8^P$``````!C[````````"```````````
M``````````@`````````"`````````"+````!@````,`````````(/L!````
M```@^P`````````"````````!``````````(`````````!``````````/```
M``@````#`````````"#]`0``````(/T```````#@`0``````````````````
M"``````````(`````````)0````!`````P``````````_P$```````#_````
M````:``````````````````````!````````"`````````"9`````0````,`
M```````````"``````````$``````'@````````````````````(````````
M````````````GP````@````#`````````'@``@``````>``!``````!8````
M````````````````"````````````````````*0````!````,```````````
M`````````'@``0``````-`````````````````````$``````````0``````
M```!`````P````````````````````````"L``$``````*T`````````````
5```````!````````````````````
